@@ -21,6 +21,7 @@ __all__ = [
 print_py = print
 from .logger import *
 from fastcore.basics import patch_to
+from fastcore.foundation import L
 import glob, numpy as np, pandas as pd, tqdm, os, sys, re
 from IPython.display import display
 import PIL
@@ -156,7 +157,7 @@ def inspect(*arrays, **kwargs):
         name = name
         typ = type(arr).__name__
 
-        if isinstance(arr, list):
+        if isinstance(arr, (list, tuple)):
             if arr == []:
                 print('[]')
             else:
@@ -454,7 +455,7 @@ def bbfy(bbs): return [BB(bb) for bb in bbs]
 def jitter(bbs, noise):
     return [BB(bb).jitter(noise) for bb in bbs]
 
-class L(list):
+class L_old(list):
     def __getitem__(self, keys):
         if isinstance(keys, (int, slice)): return list.__getitem__(self, keys)
         return L([self[k] for k in keys])
